Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(220)

Unified Diff: printing/print_dialog_gtk_interface.h

Issue 8201027: Move margin processing code to the browser process. (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: Fix issue that turned up on Windows Created 9 years, 2 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: printing/print_dialog_gtk_interface.h
diff --git a/printing/print_dialog_gtk_interface.h b/printing/print_dialog_gtk_interface.h
index 4fb9341d87687e4a34e6fab75846c73c750878aa..22de95c82dd1118e9832f3ceab8a1fddf1d659ce 100644
--- a/printing/print_dialog_gtk_interface.h
+++ b/printing/print_dialog_gtk_interface.h
@@ -11,6 +11,7 @@
namespace printing {
class Metafile;
+class PrintSettings;
// An interface for GTK printing dialogs. Classes that live outside of
// printing/ can implement this interface and get threading requirements
@@ -20,12 +21,13 @@ class PrintDialogGtkInterface {
// Tell the dialog to use the default print setting.
virtual void UseDefaultSettings() = 0;
// Update the dialog to use |settings| and |ranges|, where |settings| is a
// dictionary of settings with possible keys from
// printing/print_job_constants.h. Only used when printing without the system
// print dialog. E.g. for Print Preview. Returns false on error.
- virtual bool UpdateSettings(const base::DictionaryValue& settings,
- const PageRanges& ranges) = 0;
+ virtual bool UpdateSettings(const base::DictionaryValue& job_settings,
+ const PageRanges& ranges,
+ PrintSettings* settings) = 0;
// Shows the dialog and handles the response with |callback|. Only used when
// printing with the native print dialog.
@@ -20,12 +21,13 @@ class PrintDialogGtkInterface {
// Tell the dialog to use the default print setting.
virtual void UseDefaultSettings() = 0;
- // Update the dialog to use |settings| and |ranges|, where |settings| is a
- // dictionary of settings with possible keys from
+ // Update the dialog to use |job_settings| and |ranges|, where |job_settings|
+ // is a dictionary of settings with possible keys from
// printing/print_job_constants.h. Only used when printing without the system
// print dialog. E.g. for Print Preview. Returns false on error.

Powered by Google App Engine
This is Rietveld 408576698